@@ -77,7 +77,7 @@ def model_complete_simple(directory):
 
     model = Model('NewDevelopment', [building], [tree_canopy])
 
-    dest_file = os.path.join(directory, 'model_complete_simple.json')
+    dest_file = os.path.join(directory, 'model_complete_simple.dfjson')
     with open(dest_file, 'w') as fp:
         json.dump(model.to_dict(), fp, indent=4)
 
